==> beast-trans-api-2.2.9-20231222.075144-4-sources.jar: com/thebeastshop/trans/dto/TsLogisticsBasicQueryDTO.java <==
package com.thebeastshop.trans.dto;

import com.thebeastshop.common.BaseDO;
import com.thebeastshop.salesorder.vo.pub.SoPsOrderVO;
import com.thebeastshop.salesorder.vo.pub.SoPsPackageDeliveryInfoVO;
import com.thebeastshop.trans.enums.TsLogisticsTypeEnum;

/**
 * <p>Title: thebeastshop</p>
 * <p>Copyright: Copyright (c) 2016</p>
 * @author Bryan Zhang
 * @date 2017-2-10
 * @description
 */
public class TsLogisticsBasicQueryDTO extends BaseDO {


	private static final long serialVersionUID = 1L;

	private String logisticCode;

	private TsLogisticsTypeEnum type;

	private SoPsOrderVO order;

	private SoPsPackageDeliveryInfoVO delivery;

	public TsLogisticsBasicQueryDTO(String logisticCode, TsLogisticsTypeEnum type) {
		this.logisticCode = logisticCode;
		this.type = type;
	}

	public TsLogisticsBasicQueryDTO(String logisticCode, TsLogisticsTypeEnum type,
									SoPsOrderVO order, SoPsPackageDeliveryInfoVO delivery) {
		this.logisticCode = logisticCode;
		this.type = type;
		this.order = order;
		this.delivery = delivery;
	}

	public String getLogisticCode() {
		return logisticCode;
	}

	public void setLogisticCode(String logisticCode) {
		this.logisticCode = logisticCode;
	}

	public TsLogisticsTypeEnum getType() {
		return type;
	}

	public void setType(TsLogisticsTypeEnum type) {
		this.type = type;
	}

	public SoPsOrderVO getOrder() {
		return order;
	}

	public void setOrder(SoPsOrderVO order) {
		this.order = order;
	}

	public SoPsPackageDeliveryInfoVO getDelivery() {
		return delivery;
	}

	public void setDelivery(SoPsPackageDeliveryInfoVO delivery) {
		this.delivery = delivery;
	}
}

==> beast-trans-api-2.3.1-20240311.082505-7-sources.jar: com/thebeastshop/trans/dto/TsLogisticsBasicQueryDTO.java <==
package com.thebeastshop.trans.dto;

import com.thebeastshop.common.BaseDO;
import com.thebeastshop.salesorder.vo.pub.SoPsOrderVO;
import com.thebeastshop.salesorder.vo.pub.SoPsPackageDeliveryInfoVO;
import com.thebeastshop.trans.enums.TsLogisticsTypeEnum;

/**
 * <p>Title: thebeastshop</p>
 * <p>Copyright: Copyright (c) 2016</p>
 * @author Bryan Zhang
 * @date 2017-2-10
 * @description
 */
public class TsLogisticsBasicQueryDTO extends BaseDO {

	private static final long serialVersionUID = 1L;

	private String logisticCode;

	private TsLogisticsTypeEnum type;

	private SoPsOrderVO order;

	private SoPsPackageDeliveryInfoVO delivery;

	public TsLogisticsBasicQueryDTO(String logisticCode, TsLogisticsTypeEnum type) {
		this.logisticCode = logisticCode;
		this.type = type;
	}

	public TsLogisticsBasicQueryDTO(String logisticCode, TsLogisticsTypeEnum type, SoPsOrderVO order, SoPsPackageDeliveryInfoVO delivery) {
		this.logisticCode = logisticCode;
		this.type = type;
		this.order = order;
		this.delivery = delivery;
	}

	public String getLogisticCode() {
		return logisticCode;
	}

	public void setLogisticCode(String logisticCode) {
		this.logisticCode = logisticCode;
	}

	public TsLogisticsTypeEnum getType() {
		return type;
	}

	public void setType(TsLogisticsTypeEnum type) {
		this.type = type;
	}

	public SoPsOrderVO getOrder() {
		return order;
	}

	public void setOrder(SoPsOrderVO order) {
		this.order = order;
	}

	public SoPsPackageDeliveryInfoVO getDelivery() {
		return delivery;
	}

	public void setDelivery(SoPsPackageDeliveryInfoVO delivery) {
		this.delivery = delivery;
	}

}
